@@ -4,7 +4,7 @@
  *
  * Copyright (c) 1999-2009 Ethan Galstad (http://www.nagios.org)
  * Copyright (c) 2009-2013 Nagios Core Development Team and Community Contributors
- * Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2015 Icinga Development Team (http://www.icinga.org)
  *
  * Description:
  *
@@ -396,7 +396,7 @@ int main(int argc, char **argv, char **env) {
 
 	if (daemon_mode == FALSE) {
 		printf("\n%s %s\n", PROGRAM_NAME , PROGRAM_VERSION);
-		printf("Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)\n");
+		printf("Copyright (c) 2009-2015 Icinga Development Team (http://www.icinga.org)\n");
 		printf("Copyright (c) 2009-2013 Nagios Core Development Team and Community Contributors\n");
 		printf("Copyright (c) 1999-2009 Ethan Galstad\n");
 		printf("Last Modified: %s\n", PROGRAM_MODIFICATION_DATE);
@@ -708,6 +708,9 @@ int main(int argc, char **argv, char **env) {
 			/* write log version/info */
 			write_log_file_info(NULL);
 
+			/* set up the file descriptor registry, for use by even brokers */
+			init_registered_fds();
+
 #ifdef USE_EVENT_BROKER
 			/* load modules */
 			if (neb_load_all_modules() != OK) {
