@@ -4,7 +4,7 @@
  *
  * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
  * Copyright (c) 2009-2013 Nagios Core Development Team and Community Contributors
- * Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2015 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -27,8 +27,8 @@
 #define PROGRAM_NAME "Icinga"
 #define PROGRAM_NAME_UC "ICINGA"
 #define PROGRAM_NAME_LC "icinga"
-#define PROGRAM_VERSION "1.11.6"
-#define PROGRAM_MODIFICATION_DATE "08-06-2014"
+#define PROGRAM_VERSION "1.13.3"
+#define PROGRAM_MODIFICATION_DATE "07-15-2015"
 
 /*#define DEBUG_CHECK_IPC 1 */
 /*#define DEBUG_CHECK_IPC2 1*/
@@ -319,6 +319,9 @@
 /* for disabled notifications expiry */
 #define CMD_DISABLE_NOTIFICATIONS_EXPIRE_TIME		176
 
+/* Acknowledge host and its services */
+#define CMD_ACKNOWLEDGE_HOST_SVC_PROBLEM		177
+
 /* custom command introduced in Nagios 3.x */
 #define CMD_CUSTOM_COMMAND                              999
 #define CMD_INTERNAL_CHANGE_HOST_CHECK_RETRY_INTERVAL   1001
