@@ -4,7 +4,7 @@
  *
  * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
  * Copyright (c) 2009-2013 Nagios Core Development Team and Community Contributors
- * Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2015 Icinga Development Team (http://www.icinga.org)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -396,6 +396,10 @@ typedef struct dbuf_struct{
 	unsigned long chunk_size;
         }dbuf;
 
+int init_registered_fds(void);
+int register_fd(int fd);
+int deregister_fd(int fd);
+int close_registered_fds(void);
 
 #define CHECK_STATS_BUCKETS                  15
 
