@@ -1,8 +1,8 @@
 -- --------------------------------------------------------
 -- pgsql.sql
--- DB definition for Postgresql
+-- DB definition for IDO Postgresql
 --
--- Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
+-- Copyright (c) 2009-2015 Icinga Development Team (https://www.icinga.org)
 --
 -- --------------------------------------------------------
 
@@ -365,6 +365,7 @@ CREATE TABLE  icinga_customvariables (
   has_been_modified INTEGER  default 0,
   varname TEXT  default '',
   varvalue TEXT  default '',
+  is_json INTEGER  default 0,
   CONSTRAINT PK_customvariable_id PRIMARY KEY (customvariable_id) ,
   CONSTRAINT UQ_customvariables UNIQUE (object_id,config_type,varname)
 ) ;
@@ -384,6 +385,7 @@ CREATE TABLE  icinga_customvariablestatus (
   has_been_modified INTEGER  default 0,
   varname TEXT  default '',
   varvalue TEXT  default '',
+  is_json INTEGER  default 0,
   CONSTRAINT PK_customvariablestatus_id PRIMARY KEY (customvariablestatus_id) ,
   CONSTRAINT UQ_customvariablestatus UNIQUE (object_id,varname)
 ) ;
@@ -559,9 +561,9 @@ CREATE TABLE  icinga_hostdependencies (
   fail_on_up INTEGER  default 0,
   fail_on_down INTEGER  default 0,
   fail_on_unreachable INTEGER  default 0,
-  CONSTRAINT PK_hostdependency_id PRIMARY KEY (hostdependency_id) ,
-  CONSTRAINT UQ_hostdependencies UNIQUE (instance_id,config_type,host_object_id,dependent_host_object_id,dependency_type,inherits_parent,fail_on_up,fail_on_down,fail_on_unreachable)
+  CONSTRAINT PK_hostdependency_id PRIMARY KEY (hostdependency_id)
 ) ;
+CREATE INDEX idx_hostdependencies ON icinga_hostdependencies(instance_id,config_type,host_object_id,dependent_host_object_id,dependency_type,inherits_parent,fail_on_up,fail_on_down,fail_on_unreachable);
 
 -- --------------------------------------------------------
 
@@ -924,10 +926,12 @@ CREATE TABLE  icinga_processevents (
 CREATE TABLE  icinga_programstatus (
   programstatus_id bigserial,
   instance_id bigint default 0,
+  program_version TEXT  default NULL,
   status_update_time timestamp with time zone default '1970-01-01 00:00:00',
   program_start_time timestamp with time zone default '1970-01-01 00:00:00',
   program_end_time timestamp with time zone default '1970-01-01 00:00:00',
   is_currently_running INTEGER  default 0,
+  endpoint_name TEXT  default '',
   process_id bigint default 0,
   daemon_mode INTEGER  default 0,
   last_command_check timestamp with time zone default '1970-01-01 00:00:00',
@@ -1048,9 +1052,9 @@ CREATE TABLE  icinga_servicedependencies (
   fail_on_warning INTEGER  default 0,
   fail_on_unknown INTEGER  default 0,
   fail_on_critical INTEGER  default 0,
-  CONSTRAINT PK_servicedependency_id PRIMARY KEY (servicedependency_id) ,
-  CONSTRAINT UQ_servicedependencies UNIQUE (instance_id,config_type,service_object_id,dependent_service_object_id,dependency_type,inherits_parent,fail_on_ok,fail_on_warning,fail_on_unknown,fail_on_critical)
+  CONSTRAINT PK_servicedependency_id PRIMARY KEY (servicedependency_id)
 ) ;
+CREATE INDEX idx_servicedependencies ON icinga_servicedependencies(instance_id,config_type,service_object_id,dependent_service_object_id,dependency_type,inherits_parent,fail_on_ok,fail_on_warning,fail_on_unknown,fail_on_critical);
 
 -- --------------------------------------------------------
 
@@ -1629,5 +1633,5 @@ CREATE INDEX commenthistory_delete_idx ON icinga_commenthistory (instance_id, co
 -- set dbversion
 -- -----------------------------------------
 
-SELECT updatedbversion('1.11.6');
+SELECT updatedbversion('1.13.0');
 
