@@ -2,7 +2,7 @@
  * IDO2DB.C - IDO To Database Daemon
  *
  * Copyright (c) 2005-2008 Ethan Galstad
- * Copyright (c) 2009-2014 Icinga Development Team (http://www.icinga.org)
+ * Copyright (c) 2009-2015 Icinga Development Team (http://www.icinga.org)
  *
  **************************************************************/
 
@@ -30,6 +30,7 @@
 #endif
 
 extern int use_ssl;
+extern int use_transactions;
 
 extern int errno;
 
@@ -101,6 +102,7 @@ char *sigs[35] = {"EXIT", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "F
 
 int main(int argc, char **argv) {
 	int result = IDO_OK;
+	ido2db_idi idi_schema;
 
 #ifdef DEBUG_MEMORY
 	mtrace();
@@ -115,7 +117,6 @@ int main(int argc, char **argv) {
 	int numdrivers;
 	driver = NULL;
 #endif
-ido2db_idi idi_schema;
 #ifdef USE_ORACLE
 	unsigned int v1,v2;
 #endif
@@ -661,6 +662,14 @@ int ido2db_process_config_var(char *arg) {
 		if ((libdbi_driver_dir = strdup(val)) == NULL)
 			return IDO_ERROR;
 	}
+	else if (!strcmp(var, "use_transactions")) {
+		if (strlen(val) == 1) {
+			if (isdigit((int)val[strlen(val)-1]) != IDO_FALSE)
+				use_transactions = atoi(val);
+			else
+				use_transactions = 0;
+		}
+	}
 	/* DEPRECATED variables */
 	else if (!strcmp(var, "clean_realtime_tables_on_core_startup")) {
 		log_deprecation_warning(var);
@@ -1655,7 +1664,12 @@ int ido2db_handle_client_connection(int sd, ido2db_proxy *proxy) {
 #ifdef DEBUG_IDO2DB2
 		printf("BYTESREAD: %d\n", result);
 #endif
-		ido2db_log_debug_info(IDO2DB_DEBUGL_PROCESSINFO, 2, "BYTESREAD: %d\n", result);
+		ido2db_log_debug_info(IDO2DB_DEBUGL_PROCESSINFO, 2, "ido2db_handle_client_connection() BYTESREAD: %d\n", result);
+		if (result > 0 && result < 50) {
+			ido2db_log_debug_info(IDO2DB_DEBUGL_PROCESSINFO, 2,
+			    "ido2db_handle_client_connection() Small packet (%d octets) -- skipping.\n", result);
+			continue;
+		}
 
 		/* append data we just read to dynamic buffer */
 		buf[result] = '\x0';
@@ -1689,7 +1703,9 @@ int ido2db_handle_client_connection(int sd, ido2db_proxy *proxy) {
 
 			if (in_transaction == IDO_FALSE) {
 				io_since_last_commit = 0;
+#ifdef DEBUG_IDO2DB2
 				printf("Committing...\n");
+#endif
 			}
 
 			if (in_transaction == IDO_FALSE && ido2db_db_tx_commit(&idi) != IDO_OK)
